@@ -9,6 +9,7 @@
 #define __GNOME_CD_H__
 
 #include <gtk/gtkwidget.h>
+#include <gtk/gtkstatusicon.h>
 #include <gtk/gtktooltips.h>
 
 #include <pango/pango.h>
@@ -20,18 +21,10 @@
 #include "cd-selection.h"
 #include "preferences.h"
 #include "cdrom.h"
-#include "eggtrayicon.h"
 
 #define NUMBER_OF_DISPLAY_LINES 5
 
 /* Stock icons */
-#define GNOME_CD_PLAY "media-play"
-#define GNOME_CD_PAUSE "media-pause"
-#define GNOME_CD_STOP "media-stop"
-#define GNOME_CD_PREVIOUS "media-prev"
-#define GNOME_CD_NEXT "media-next"
-#define GNOME_CD_FFWD "media-ffwd"
-#define GNOME_CD_REWIND "media-rewind"
 #define GNOME_CD_EJECT "media-eject"
 
 typedef struct _GnomeCDDiscInfo {
@@ -56,9 +49,7 @@ typedef struct _GCDTheme {
 } GCDTheme;
 
 struct _GnomeCD {
-	GtkWidget *tray;
-	GtkWidget *tray_icon;
-	GtkTooltips *tray_tips;
+	GtkStatusIcon *tray;
 
 	GtkWidget *window;
 	GtkWidget *vbox;
@@ -69,6 +60,7 @@ struct _GnomeCD {
 	GtkWidget *menu;
 	GtkWidget *slider;
 	GtkTooltips *tooltips;
+	GConfClient * client;
 
 	GtkWidget *trackeditor_b, *properties_b;
 
@@ -126,6 +118,5 @@ void make_popup_menu (GnomeCD *gcd,
                 GdkEventButton *event, gboolean iconify);
 
 void tray_icon_create (GnomeCD *gcd);
-GConfClient *client;
 
 #endif
