@@ -1,6 +1,7 @@
 #include <string.h>
+#include <gst/gst.h>
 
-#include "libgnome/gnome-i18n.h"
+#include <glib/gi18n.h>
 #include "gmp-util.h"
 #include "audio-profile.h"
 #include "audio-profile-private.h"
@@ -100,8 +101,8 @@ gm_audio_profile_init (GMAudioProfile *profile)
   g_return_if_fail (profiles != NULL);
 
   profile->priv = g_new0 (GMAudioProfilePrivate, 1);
-  profile->priv->name = g_strdup (_("<not named>"));
-  profile->priv->description = g_strdup (_("<not described>"));
+  profile->priv->name = g_strdup (_("<no name>"));
+  profile->priv->description = g_strdup (_("<no description>"));
   profile->priv->pipeline = g_strdup ("identity");
   profile->priv->extension = g_strdup ("wav");
 }
@@ -861,8 +862,20 @@ gm_audio_profile_get_active_list (void)
     GMAudioProfile *profile;
 
     profile = (GMAudioProfile *) list->data;
-    if (gm_audio_profile_get_active (profile))
-      new_list = g_list_prepend (new_list, list->data);
+    if (gm_audio_profile_get_active (profile)) {
+      const gchar *pipe = gm_audio_profile_get_pipeline (profile);
+      gchar *test = g_strdup_printf ("fakesrc ! %s ! fakesink", pipe);
+      GstElement *p;
+      GError *err = NULL;
+      if ((p = gst_parse_launch (test, &err)) && err == NULL) {
+        new_list = g_list_prepend (new_list, list->data);
+        g_object_unref (p);
+      } else {
+        g_object_unref (p);
+        g_error_free (err);
+      }
+      g_free (test);
+    }
     list = g_list_next (list);
   }
 
@@ -1010,7 +1023,7 @@ gm_audio_profile_create (const char  *name,
 
   gconf_client_set_string (conf,
                            key,
-                           _("identity"),
+                           "identity",
                            &err);
   if (err != NULL) g_print ("ERROR: msg: %s\n", err->message);
   BAIL_OUT_CHECK ();
@@ -1021,7 +1034,7 @@ gm_audio_profile_create (const char  *name,
 
   gconf_client_set_string (conf,
                            key,
-                           _("wav"),
+                           "wav",
                            &err);
   if (err != NULL) g_print ("ERROR: msg: %s\n", err->message);
   BAIL_OUT_CHECK ();
